nvector.objects.GeoPath — nvector 0.7.5 documentation

# nvector.objects.GeoPath

class `GeoPath`(point_a, point_b)

  > Geographical path between two positions in Frame E

  Parameters
    point_a, point_b: Nvector, GeoPoint or ECEFvector objects

      The path is defined by the line between point A and B, decomposed in E.

  Notes

  Please note that either point A or point B or both might be a vector of points. In this case the GeoPath instance represents all the paths between the points of A and the corresponding points of B.

  `__init__`(self, point_a, point_b)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `__init__`(self, point_a, point_b) | Initialize self.
  `closest_point_on_great_circle`(self, point) | Returns closest point on great circle path to the point.
  `closest_point_on_path`(self, point) | Returns closest point on great circle path segment to the point.
  `cross_track_distance`(self, point[, method, …]) | Returns cross track distance from path to point.
  `ecef_vectors`(self) | Returns point_a and point_b as ECEF-vectors
  `geo_points`(self) | Returns point_a and point_b as geo-points
  `interpolate`(self, ti) | Returns the interpolated point along the path
  `intersect`(self, path) | Returns the intersection(s) between the great circles of the two paths
  `intersection`(\*args, \*\*kwds) | intersection is deprecated!
  `nvector_normals`(self) | Returns nvector normals for position a and b
  `nvectors`(self) | Returns point_a and point_b as n-vectors
  `on_great_circle`(self, point[, atol]) | Returns True if point is on the great circle within a tolerance.
  `on_path`(self, point[, method, rtol, atol]) | Returns True if point is on the path between A and B witin a tolerance.
  `track_distance`(self[, method, radius]) | Returns the path distance computed at the average height.

  Attributes

  `positionA` | Deprecated use point_a instead
  `positionB` | Deprecated use point_a instead